#
# Copyright (c) 2002-2017 by Dell Inc.
#
# All rights reserved.  This software may not be copied, disclosed,
# transferred, or used except in accordance with a license granted
# by Dell Inc.  This software embodies proprietary information
# and trade secrets of Dell Inc.
#

#---------------------------------------------------------------
#
#   Function:   findAdjacentDriveForDiskId(DISKID, IWANT)
#
#   Description:
#   Script to print the drive adjacent to the DISKID passed in. The second
#   arg details whether you the user wants the drive to right or to the left
#   in the raidset. The adjacency wraps if the drive is on either end of the raidset.
#
#  > Usage: provide(via pipe or file) the output from raidtool to this script.
#  > e.g.
#  > raidtool | awk -v DISKID=15r -v IWANT=leftside -f ./alib/findAdjacentDriveForDiskId.awk
#  > raidtool | awk -v DISKID=f -v IWANT=leftside -f ./alib/findAdjacentDriveForDiskId.awk
#
#   Inputs:
#       _DISKID_   the disk id you wish information about.
#
#       _IWANT_   The side you want the adjacent drive id. The choices are _leftside_ or _rightside_
#
#
#   Returns:
#       return the adjacent drive ID or NULL
#


# library functions
function sizeof(a, i,n) { for(i in a) n++ ; return n }

function join(a,start,end,sep,    result,i) {
    sep   = sep   ? start :  " "
    start = start ? start : 1
    end   = end   ? end   : sizeof(a)
    if (sep == SUBSEP) # magic value
       sep = ""
    result = a[start]
    for (i = start + 1; i <= end; i++)
        result = result sep a[i]
    return result
}

BEGIN {
    i = 0
    rs = 0
    IWANT=toupper(IWANT)
}
# begPat  , endPat
/RAID LUN/,/bytes/ {
    if (match ($0, /^RAID LUN/ )){ raidLun[i++]=$0}
    if (match ($0, / Drives /  )){ raidLun[i++]=$0}
    if (match ($0, / RAID 1/   )){ raidLun[i++]=$0}
    if (match ($0, / RAID 5/   )){ raidLun[i++]=$0}
    if (match ($0, / RAID 6/   )){ raidLun[i++]=$0}
    if (match ($0, / Capacity /)){ raidLun[i++]=$0}
}

END {
    # LUN specific data is found in groups of 4 from a beginning offset
    lunsFound=i / 4
    for (i = 0; i < lunsFound; i++){
        #
        lunRecBase= 4 * i

        DRIVES    = raidLun[lunRecBase+1]
        RAIDTYPE  = raidLun[lunRecBase+2]
        split(DRIVES, data," ");
        gsub(/\(/, "", data[3] )
        gsub(/\)/, "", data[3] )

        split (data[3], diskIDS, ",")

        split (RAIDTYPE, data, " ")
        RaidType=tolower(data[2])

        # build the raidset strings
        dCount=0
        for (j in diskIDS){ dCount++}
        DriveString=""
        # with a REAL awk we could use a nice 'select' statement but on the array... Noooooo
        if (RaidType == 50){
            for (k =1; k <= dCount; k++ ){
                if ( (k == dCount / 2)){
                    DriveString=DriveString "," diskIDS[k]
                    gsub(/^,/, "", DriveString )
                    raidSet[rs++]=DriveString
                    DriveString=""
                }
                else{
                    DriveString=DriveString "," diskIDS[k]
                }
            }
        }
        if (RaidType == 10){
            for (k =1; k <= dCount; k++ ){
                if ( (k % 2) == 0){
                    DriveString=DriveString "," diskIDS[k]
                    raidSet[rs++]=DriveString
                    DriveString=""
                }
                else{
                    DriveString=DriveString "," diskIDS[k]
                }
            }
        }
        if (RaidType == 5 || RaidType == 6){
            for (k =1; k <= dCount; k++ ){
                DriveString=DriveString "," diskIDS[k]
            }
        }

        gsub(/^,/, "", DriveString )
        raidSet[rs++]=DriveString

    }

    # dump out the current lun line of info
    for (rs in raidSet){
        split (raidSet[rs], currentRaidset, ",")
        max=sizeof(currentRaidset)

        for (dr in currentRaidset){
            if (currentRaidset[dr] == DISKID){
                # "We found the diskID of interest in the currentRaidSet now find what's around it."
                left = dr -1
                right= dr +1
                if (dr == 1)   left = max
                if (dr == max) right= 1
                if(IWANT ~ "LEFTSIDE"){
                    print currentRaidset[left]
                }
                if(IWANT ~ "RIGHTSIDE"){
                    print currentRaidset[right]
                }
            }
        }
    }
}
