#
# @(#) Script to filter out the details of particular LUN(default is LUN 0 )
#
# Copyright (c) 2002-2017 by Dell Inc.
#
# All rights reserved.  This software may not be copied, disclosed,
# transferred, or used except in accordance with a license granted
# by Dell Inc.  This software embodies proprietary information
# and trade secrets of Dell Inc.
#

#---------------------------------------------------------------
#
#   Function:   findLunInfoForDiskId(DISKID, IWANT)
#
#   Description:
#   Script to parse out the relevant information from the raidset LUN of interest when given just a diskid.
#
# > Usage: with data from raidtool find the information the user wants for a particular diskID.
# > e.g.  awk -v DISKID=1 -v IWANT=raidtype -f ./alib/findLunInfoForDiskId raid50.txt
# > raidtool | awk -v DISKID=1 -v IWANT=raidtype -f ./alib/findLunInfoForDiskId.awk
#
#  IMPORTANT: you must pass in both the  DISKID=1 and IWANT vars.
#
#             where IWANT is one of LUN, DRIVES, RAIDTYPE or CAPACITY.
#
#   Inputs:
#       _DISKID_   the disk id you wish information about.
#
#       _IWANT_   The info you are requesting. The choices are LUN, DRIVES, RAIDTYPE or CAPACITY
#
#   Returns:
#       return the requested info for the drive ID or NULL
#



BEGIN {
    IGNORECASE = 1
    i=0
    IWANT=toupper(IWANT)
}
# begPat  , endPat
/RAID LUN/,/bytes/ {
    if (match ($0, /^RAID LUN/ )){ raidLun[i++]=$0}
    if (match ($0, / Drives /  )){ raidLun[i++]=$0}
    if (match ($0, / RAID 1/   )){ raidLun[i++]=$0}
    if (match ($0, / RAID 5/   )){ raidLun[i++]=$0}
    if (match ($0, / RAID 6/   )){ raidLun[i++]=$0}
    if (match ($0, / Capacity /)){ raidLun[i++]=$0}
}
END {

    # LUN specific data is found in groups of 4 from a beginning offset
    lunsFound=i / 4
    # leave this in for debug
    #for (k in raidLun){
    #    print "raidLun["k"]" raidLun[k]
    #}


    for (i = 0; i <= lunsFound; i++){
    #
        lunRecBase= 4 * i     # this works because LUN var is initialized implicitly to 0 unless passed by user with -v LUN=xxx
        LUN       = raidLun[lunRecBase]
        DRIVES    = raidLun[lunRecBase+1]
        RAIDTYPE  = raidLun[lunRecBase+2]
        CAPACITY  = raidLun[lunRecBase+3]
        # split the drives line
        split(DRIVES,rdrives," ");
        gsub(/\(/, "", rdrives[3] )
        gsub(/\)/, "", rdrives[3] )
        split(rdrives[3], disks, ",")
        for(drive in disks){
            if ( disks[drive] == DISKID || disks[drive] == DISKID"r" || disks[drive] == DISKID"f"  ){
                if(IWANT ~ "LUN"){
                    split(LUN, data, " ")
                    print data[3]
                }
                if (IWANT ~ "DRIVES"){
                    split(DRIVES, data," ");
                    gsub(/\(/, "", data[3] )
                    gsub(/\)/, "", data[3] )
                    gsub(/\,/, " ", data[3] )
                    print data[3]
                }
                if (IWANT ~ "RAIDTYPE"){
                    split (RAIDTYPE, data, " ")
                    print tolower(data[1] data[2])
                }
                if (IWANT ~ "CAPACITY"){
                    split(CAPACITY, data, " ")
                    gsub(/\,/, "", data[2] )
                    print data[2]
                }
            }
        }
    }
}
