#
# @(#) Script to filter out the details of particular LUN(default is LUN 0 )
#
# Copyright (c) 2002-2017 by Dell Inc.
#
# All rights reserved.  This software may not be copied, disclosed,
# transferred, or used except in accordance with a license granted
# by Dell Inc.  This software embodies proprietary information
# and trade secrets of Dell Inc.

#---------------------------------------------------------------
#
#   Function:   findLunInfoForLunId(DISKID, IWANT)
#
#   Description:
#   Script to parse out the relevant information from the raidset LUN of interest
#
#
# > Usage: with data from raidtool find the information the user wants for a particular diskID.
# > awk -v  LUN=1 -f ./alib/findLunInfoForLunId raid50.txt
# > e.g.
# > raidtool | awk -v LUN=1  -f ./alib/findLunInfoForLunId.awk
#
#  IMPORTANT: LUN will default to zero if not passed in
#
#
#   Inputs:
#       _LUN_   the lun id you wish information about.
#
#
#
#   Returns:
#       return the info for LUN, DRIVES, RAIDTYPE or CAPACITY of the requested lun
#

BEGIN {
    IGNORECASE = 1
    i=0
}
# begPat  , endPat
/RAID LUN/,/bytes/ {
    raidLun[i++]=$0
}
END {
      # LUN specific data is found in groups of 4 from a beginning offset
      lunRecBase= 0  # default in case no args sent down
      #
      lunRecBase= 4 * LUN     # this works because LUN var is initialized implicitly to 0 unless passed by user with -v LUN=xxx
      LUN       = raidLun[lunRecBase]
      DRIVES    = raidLun[lunRecBase+1]
      RAIDTYPE  = raidLun[lunRecBase+2]
      CAPACITY  = raidLun[lunRecBase+3]

      print LUN
      print DRIVES
      print RAIDTYPE
      print CAPACITY

}
