#
#
# Copyright (c) 2002-2017 by Dell Inc.
#
# All rights reserved.  This software may not be copied, disclosed,
# transferred, or used except in accordance with a license granted
# by Dell Inc.  This software embodies proprietary information
# and trade secrets of Dell Inc.
#

#---------------------------------------------------------------
#
#   Function:   findRaidsetForDiskId(DISKID)
#
#   Description:
#   Script to print the raidset occurance containing passed diskID
#
# > usage: raidsetRet=`raidtool | awk -v DISKID=$diskID  -f ./alib/findRaidsetForDiskId.awk`
# > e.g.
# > raidtool | awk -v DISKID=15r  -f ./alib/findRaidsetForDiskId.awk
#
#   Inputs:
#       _DISKID_   the disk id you wish information about.
#
#
#
#   Returns:
#       return the raidset containing the diskID or null
#

BEGIN {
    i = 0
    rs = 0
}
# begPat  , endPat
/RAID LUN/,/bytes/ {
    if (match ($0, /^RAID LUN/ )){ raidLun[i++]=$0}
    if (match ($0, / Drives /  )){ raidLun[i++]=$0}
    if (match ($0, / RAID 1/   )){ raidLun[i++]=$0}
    if (match ($0, / RAID 5/   )){ raidLun[i++]=$0}
    if (match ($0, / RAID 6/   )){ raidLun[i++]=$0}
    if (match ($0, / Capacity /)){ raidLun[i++]=$0}
}

END {
    # LUN specific data is found in groups of 4 from a beginning offset
    lunsFound=i / 4
    for (i = 0; i < lunsFound; i++){
        #
        lunRecBase= 4 * i

        DRIVES    = raidLun[lunRecBase+1]
        RAIDTYPE  = raidLun[lunRecBase+2]
        split(DRIVES, data," ");
        gsub(/\(/, "", data[3] )
        gsub(/\)/, "", data[3] )

        split (data[3], diskIDS, ",")

        split (RAIDTYPE, data, " ")
        RaidType=tolower(data[2])

        # build the raidset strings
        dCount=0
        for (j in diskIDS){ dCount++}
        DriveString=""
        # with a REAL awk we could use a nice 'select' statement but on the array... Noooooo
        if (RaidType == 50){
            for (k =1; k <= dCount; k++ ){
                if ( (k == dCount / 2)){
                    DriveString=DriveString "," diskIDS[k]
                    gsub(/^,/, "", DriveString )
                    raidSet[rs++]=DriveString
                    DriveString=""
                }
                else{
                    DriveString=DriveString "," diskIDS[k]
                }
            }
        }
        if (RaidType == 10){
            for (k =1; k <= dCount; k++ ){
                if ( (k % 2) == 0){
                    DriveString=DriveString "," diskIDS[k]
                    raidSet[rs++]=DriveString
                    DriveString=""
                }
                else{
                    DriveString=DriveString "," diskIDS[k]
                }
            }
        }
        if (RaidType == 5 || RaidType == 6){
            for (k =1; k <= dCount; k++ ){
                DriveString=DriveString "," diskIDS[k]
            }
        }
        gsub(/^,/, "", DriveString )
        raidSet[rs++]=DriveString
    }
    # dump out the current lun line of info
    for (rs in raidSet){
        split (raidSet[rs], currentRaidset, ",")

        for (dr in currentRaidset){
            if (currentRaidset[dr] == DISKID){
                print rs

            }
        }
        # leave next line for debug
        #print "raidSet["rs"]="raidSet[rs]
    }

}
