#
# @(#) Script to filter out the details of particular LUN(default is LUN 0 )
#
# Copyright (c) 2002-2017 by Dell Inc.
#
# All rights reserved.  This software may not be copied, disclosed,
# transferred, or used except in accordance with a license granted
# by Dell Inc.  This software embodies proprietary information
# and trade secrets of Dell Inc.
#

#---------------------------------------------------------------
#
#   Function:   multiLun( LUN )
#
#   Description:
#   Script to parse out the relevant information from the raidset LUN of interest.
#
# > Usage:  provide(via pipe or file) the output for the LUN of interest from raidtool to this script
# > e.g.  awk -v LUN=1 -f ./alib/multiLun.awk raid50.txt
#
#   Inputs:
#       _LUN_   the lun id you wish information about.(default is lun 0 )
#
#   Returns:
#       return the info for LUN, DRIVES, RAIDTYPE or CAPACITY of the requested lun
#

BEGIN {
    IGNORECASE = 1
    i=0
}
# begPat  , endPat
/RAID LUN/,/bytes/ {
    if (match ($0, /^RAID LUN/ )){ raidLun[i++]=$0}
    if (match ($0, / Drives /  )){ raidLun[i++]=$0}
    if (match ($0, / RAID 1/   )){ raidLun[i++]=$0}
    if (match ($0, / RAID 5/   )){ raidLun[i++]=$0}
    if (match ($0, / RAID 6/   )){ raidLun[i++]=$0}
    if (match ($0, / Capacity /)){ raidLun[i++]=$0}
}
END {
      # LUN specific data is found in groups of 4 from a beginning offset
      lunRecBase= 0  # default in case no args sent down
      #
      lunRecBase= 4 * LUN     # this works because LUN var is initialized implicitly to 0 unless passed by user with -v LUN=xxx
      LUN       = raidLun[lunRecBase]
      DRIVES    = raidLun[lunRecBase+1]
      RAIDTYPE  = raidLun[lunRecBase+2]
      CAPACITY  = raidLun[lunRecBase+3]

      print LUN
      print DRIVES
      print RAIDTYPE
      print CAPACITY

}
