#
# @(#) Script to print the reconstructing drives in a raidset of a particular LUN.
#
# Copyright (c) 2002-2017 by Dell Inc.
#
# All rights reserved.  This software may not be copied, disclosed,
# transferred, or used except in accordance with a license granted
# by Dell Inc.  This software embodies proprietary information
# and trade secrets of Dell Inc.
#

#---------------------------------------------------------------
#
#   Function:   raidDriveWithCondition( IWANT )
#
#   Description:
#   Script to return the list of drives rebuilding or failed in a raidset LUN from raidtool output
#
# > Usage: provide(via pipe or file) the output for the LUN of interest from raidtool to this script
# > e.g.  raidtool  | awk -v IWANT=recon -f ./alib/raidDriveWithCondition.awk
# >       raidtool  | awk -v IWANT=fail -f ./alib/raidDriveWithCondition.awk
#
#   Inputs:
#       _IWANT_   the 2 possible arguments are *recon* and *fail*
#
#
#   Returns:
#       prints out drive(s) that match the requested condition
#


BEGIN {
    IGNORECASE = 1
    i=0
    IWANT=toupper(IWANT)
}
/Drives \(/ {
    drives[++i] = $0
}
END {
    i=0
    for(allDrives in drives){
        split(drives[allDrives],rdrives," ");
        gsub(/\(/, "", rdrives[3] )
        gsub(/\)/, "", rdrives[3] )
        split(rdrives[3], raidSet, ",")
        for(drive in raidSet){
            if(IWANT ~ "RECON"){
                if ( match( raidSet[drive], /r/)  ){
                    retDrives = retDrives " " raidSet[drive]
                }
            }
            if(IWANT ~ "FAIL"){
                if ( match( raidSet[drive], /f/)  ){
                    retDrives = retDrives " " raidSet[drive]
                }
            }
        }
    }
    print retDrives
}
