#
# @(#) Script to print the raidset type for a LUN
#
# Copyright (c) 2002-2017 by Dell Inc.
#
# All rights reserved.  This software may not be copied, disclosed,
# transferred, or used except in accordance with a license granted
# by Dell Inc.  This software embodies proprietary information
# and trade secrets of Dell Inc.
#

#---------------------------------------------------------------
#
#   Function:   raidReverseLookup( IWANT )
#
#   Description:
# Script to parse out the relevant information from the raidtool reverse lookup
# and return the lun or lba the user asks for
#
# > Usage: with data from raidtool find the information the user wants.
# > e.g.  raidtool  -O $diskID -M $diskLBA  | awk -v IWANT=lun -f ./alib/raidReverseLookup.awk
# >      raidtool  -O $diskID -M $diskLBA  | awk -v IWANT=lba -f ./alib/raidReverseLookup.awk
#
#  IMPORTANT: you must pass in the IWANT vars where IWANT is one of *LUN* or *LBA*
#
#   Inputs:
#       _IWANT_   the 2 possible arguments are *LUN* and *LBA*
#
#   Returns:
#       prints out the requested lun or lba
#


#
BEGIN {
    IGNORECASE = 1
    i=0
    j=0
    k=0
    IWANT=toupper(IWANT)
}
/LUN:/ {
    lunLine[++i] = $0
}
/LBA =/{
    lbaLine[++j] = $0
}
/Parity/{
    lbaLine[++k] = $0
}
END {
    if(IWANT ~ "LUN"){
        split(lunLine[1],lun,":");
        print lun[2]
    }
    if(IWANT ~ "LBA"){
        split(lbaLine[1],lba,"=");
        print lba[2]
    }
    if(IWANT ~ "PARITY"){
        if ( lbaLine[1] ~ /[Pp]arity/ ){
            split(lbaLine[1],parity,"Block is a");
            print parity[2]
        }
    }

}
