#
#
# Copyright (c) 2002-2017 by Dell Inc.
#
# All rights reserved.  This software may not be copied, disclosed,
# transferred, or used except in accordance with a license granted
# by Dell Inc.  This software embodies proprietary information
# and trade secrets of Dell Inc.
#

#---------------------------------------------------------------
#
#   Function:   raidview(  )
#
#   Description: Script to emulate the raidview command
#
# > Usage: provide(via pipe or file) the output  from raidtool to this script
# > e.g.
# > raidtool | awk -f ./alib/raidview.awk
#
#
#   Inputs:
#       _NONE_
#
#   Returns:
#       prints out raidview emulated output
#

BEGIN {
    i = 0
    kilobyte = 1024
    megabyte = kilobyte * 1024
    gigabyte = megabyte * 1024
    terabyte = gigabyte * 1024;
}
# begPat  , endPat
/RAID LUN/,/bytes/ {
    if (match ($0, /^RAID LUN/ )){ raidLun[i++]=$0}
    if (match ($0, / Drives /  )){ raidLun[i++]=$0}
    if (match ($0, / RAID 1/   )){ raidLun[i++]=$0}
    if (match ($0, / RAID 5/   )){ raidLun[i++]=$0}
    if (match ($0, / RAID 6/   )){ raidLun[i++]=$0}
    if (match ($0, / Capacity /)){ raidLun[i++]=$0}
}

/Driver Status/{
    print $0
}
/Available/{
    print $0
}

END {
    printf("%-10s%-10s%-50s%-20s%-10s\n","LUN", "R", "Drives", "Size", "Status")
    print "-----------------------------------------------------------------------------------"
    # LUN specific data is found in groups of 4 from a beginning offset
    lunsFound=i / 4
    for (i = 0; i < lunsFound; i++){
        #
        lunRecBase= 4 * i     # this works because LUN var is initialized implicitly to 0 unless passed by user with -v LUN=xxx

        LUN       = raidLun[lunRecBase]
        DRIVES    = raidLun[lunRecBase+1]
        RAIDTYPE  = raidLun[lunRecBase+2]
        CAPACITY  = raidLun[lunRecBase+3]

        split(LUN, data, " ")
        LUN= data[3]
        STATUS=" "data[4]" " data[5]" " data[6]" " data[7]" " data[8]" " data[9]" " data[10]

        split(DRIVES, data," ");
        gsub(/\(/, "", data[3] )
        gsub(/\)/, "", data[3] )

        split (data[3], diskIDS, ",")
        DriveString="["

        split (RAIDTYPE, data, " ")
        RaidType=tolower(data[2])


        split(CAPACITY, data, " ")
        gsub(/\,/, "", data[2] )
        Capacity=data[2]/terabyte "TB"

        # build the raidset strings
        dCount=0
        for (j in diskIDS){ dCount++}
        DriveString="[" diskIDS[1]

        # with a REAL awk we could use a nice 'select' statement but on the array... Noooooo
        if (RaidType == 50){
            for (k =2; k <= dCount; k++ ){
                if ( (dCount / k) == 2){
                    DriveString=DriveString "," diskIDS[k] "]["
                }
                else{
                    DriveString=DriveString "," diskIDS[k]
                }
            }
            DriveString=DriveString "]"
            gsub(/\[,/, "[", DriveString )
        }
        if (RaidType == 10){
            for (k =2; k <= dCount; k++ ){
                if ( (k % 2) == 0){
                    DriveString=DriveString "," diskIDS[k] "]["
                }
                else{
                    DriveString=DriveString "," diskIDS[k]
                }
            }
            gsub(/\[,/, "[", DriveString )
            gsub(/\[$/, "", DriveString )
        }
        if (RaidType == 5 || RaidType == 6){
            for (k =2; k <= dCount; k++ ){
                DriveString=DriveString "," diskIDS[k]
            }
            DriveString=DriveString "]"
            gsub(/\[,/, "[", DriveString )
        }

        # dump out the current lun line of info
        printf("%-10s%-10s%-50s%-20s%-10s\n",LUN, RaidType, DriveString, Capacity, STATUS)
    }

}
