#!/bin/sh
#
# @(#) Script to update disk drive firmmware
#
# Copyright (c) 2010-2015 by Dell Inc.
#
# All rights reserved.  This software may not be copied, disclosed,
# transferred, or used except in accordance with a license granted
# by Dell Inc.  This software embodies proprietary information
# and trade secrets of Dell Inc.
#
# Global variables
LOCKFILE="/tmp/dfwupd.sh.lock"
UPDLOCKFILE="/tmp/update.lock"

interlock()
{

    if [ -e ${LOCKFILE} ]; then
        lastRunningPid=`cat ${LOCKFILE}`
        psRet=`ps ${lastRunningPid}`
        procFound=`echo $psRet  | awk '/[0-9]/'`
        if [ ! -z "$procFound" ]; then
            echo "Another copy of this process is already running"
            exit 88
        fi
    fi
    # we are the only process of our kind running so
    # place the current pid in the lock file.
    echo $$ > ${LOCKFILE}
    sleep 1

}

cleanup()
{
    cd /mgtdb/update
    rm -f ${LOCKFILE}
    rm -rf /mgtdb/update/dfu

    rm -f /mgtdb/update/cksum*
    rm -f /mgtdb/update/dfwupd*.bin
    rm -f /mgtdb/update/dfwdown*.bin
    rm -f /mgtdb/update/build.c
    rm -f /mgtdb/update/eql*.gz
    rm -f /mgtdb/update/eqlDriveFw.properties
    rm -f /mgtdb/update/update.sh
    rm -f /mgtdb/update/kit_V*_DriveFw_*.tgz
    # Bug 78610 - The EQLX array's local update.sh script will not catch a telnet connection drop,
    # see bug 9431 for more detail. In the event that the Telnet connection is dropped during drive
    # firmware update, this script will catch the SIGUP signal and remove the "update.lock" file preventing
    # "Another copy of update is already running" error when the next update command is attempted.  
    if [ -e "${UPDLOCKFILE}" ]; then
        rm -f ${UPDLOCKFILE}
    fi
}

#######
# Main
#######
EXSTAT=2
trap cleanup 1 2 3 6 9

# check/establish a lock file
interlock

EXSTAT=2
cd /mgtdb/update
# in the event of multiple kit files 
GZList=$(ls -t kit_V*_DriveFw_*.tgz 2>/dev/null)
GZFile=$(echo ${GZList} | awk '{print $1}') # get the newest one
# unpack ourselves.
tar xzf ${GZFile}
cp -f /build.c  /mgtdb/update/build.c

# lock and load
originaldir=`pwd`
cd dfu

g_guiMode=`echo "$@" | awk 'BEGIN{ignorecase=1}/-gui/{print $1}'`
if [ ! -z "${g_guiMode}" ]; then
    sh ./dfwupd.sh -gui
else
    sh ./dfwupd.sh $@
fi
dfwupdStatus=$?

cd ${originaldir}

#unlock
if [ -n "${LOCKFILE}" ]; then
    rm -f ${LOCKFILE}
fi
# be neat...
cleanup
exit $dfwupdStatus
